document.addEventListener('DOMContentLoaded', () => {
  // Simulated data updates
  function updateMetrics() {
    const marketCap = document.getElementById('marketCap');
    const networkValue = document.getElementById('networkValue');
    const txCount = document.getElementById('txCount');
    const activeAddresses = document.getElementById('activeAddresses');

    function formatNumber(num) {
      return num.toString().replace(/\B(?=(\d{3})+(?!\d))/g, ",");
    }

    setInterval(() => {
      marketCap.textContent = formatNumber(Math.floor(Math.random() * 1000000000000));
      networkValue.textContent = formatNumber(Math.floor(Math.random() * 800000000000));
      txCount.textContent = formatNumber(Math.floor(Math.random() * 1000000));
      activeAddresses.textContent = formatNumber(Math.floor(Math.random() * 1000000));
    }, 3000);
  }

  // Chart initialization
  function initializeCharts() {
    const chartContexts = document.querySelectorAll('canvas');
    
    chartContexts.forEach(canvas => {
      const ctx = canvas.getContext('2d');
      ctx.strokeStyle = '#818cf8';
      ctx.lineWidth = 2;
      
      // Create animated line chart
      function drawChart() {
        ctx.clearRect(0, 0, canvas.width, canvas.height);
        ctx.beginPath();
        ctx.moveTo(0, canvas.height/2);
        
        for(let i = 0; i < canvas.width; i++) {
          ctx.lineTo(i, canvas.height/2 + Math.sin(i/10 + Date.now()/1000) * 20);
        }
        
        ctx.stroke();
        requestAnimationFrame(drawChart);
      }
      
      drawChart();
    });
  }

  // Form handling
  const contactForm = document.querySelector('.contact-form');
  if(contactForm) {
    contactForm.addEventListener('submit', (e) => {
      e.preventDefault();
      alert('Thank you for your message! We will get back to you soon.');
      contactForm.reset();
    });
  }

  // Smooth scrolling
  document.querySelectorAll('a[href^="#"]').forEach(anchor => {
    anchor.addEventListener('click', function (e) {
      e.preventDefault();
      document.querySelector(this.getAttribute('href')).scrollIntoView({
        behavior: 'smooth'
      });
    });
  });

  // Initialize everything
  updateMetrics();
  initializeCharts();
});